# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`approx`](#approx): Installs the approx server and a basic configuration file
* [`approx::garbage_collect`](#approxgarbage_collect): Cronjob to run approx-gc

### Defined types

* [`approx::repository`](#approxrepository): Add a repository line to an approx proxy

## Classes

### <a name="approx"></a>`approx`

Approx apt proxy server, main class

specific repositories have to be defined with
apt::approx::repository.

#### Examples

##### hiera usage to configure repositories

```puppet
approx::config:
  debian:
    url: 'http://ftp.ch.debian.org/debian'
  debian-security:
    url: 'http://security.debian.org/debian-security'
  debian-backports:
    url: 'http://ftp.ch.debian.org/debian-backports'
```

##### Example (hiera) to create an xinetd service using puppetlabs-xinetd

```puppet
approx::create_resources:
  xinetd::service:
    approx:
      server: '/usr/sbin/approx'
      user: 'approx'

Will result in  executing:
  xinetd::service{'approx':
    server => '/usr/sbin/approx'
    user   => 'approx'
```

#### Parameters

The following parameters are available in the `approx` class:

* [`conffile`](#conffile)
* [`cache`](#cache)
* [`ensure_cache`](#ensure_cache)
* [`interval`](#interval)
* [`max_rate`](#max_rate)
* [`max_redirects`](#max_redirects)
* [`user`](#user)
* [`group`](#group)
* [`syslog`](#syslog)
* [`pdiffs`](#pdiffs)
* [`offline`](#offline)
* [`max_wait`](#max_wait)
* [`verbose`](#verbose)
* [`debug`](#debug)
* [`config`](#config)
* [`create_resources`](#create_resources)

##### <a name="conffile"></a>`conffile`

Data type: `String`

path to the configuration file

##### <a name="cache"></a>`cache`

Data type: `Optional[String]`

path of the approx cache directory

Default value: ``undef``

##### <a name="ensure_cache"></a>`ensure_cache`

Data type: `Boolean`

if true it ensures that the cache directories are created

Default value: ``true``

##### <a name="interval"></a>`interval`

Data type: `Optional[Integer]`

time in minutes after which a cached file will be considered too old to deliver

Default value: ``undef``

##### <a name="max_rate"></a>`max_rate`

Data type: `Optional[Variant[Integer, Enum['unlimited']]]`

maximum download rate from remote repositories, in bytes per second

Default value: ``undef``

##### <a name="max_redirects"></a>`max_redirects`

Data type: `Optional[Integer]`

maximum number of HTTP redirections

Default value: ``undef``

##### <a name="user"></a>`user`

Data type: `Optional[String]`

user that owns the files in cache

Default value: ``undef``

##### <a name="group"></a>`group`

Data type: `Optional[String]`

group that owns the files in cache

Default value: ``undef``

##### <a name="syslog"></a>`syslog`

Data type: `Optional[String]`

syslog facility to use when logging

Default value: ``undef``

##### <a name="pdiffs"></a>`pdiffs`

Data type: `Optional[Boolean]`

whether to support IndexFile diffs

Default value: ``undef``

##### <a name="offline"></a>`offline`

Data type: `Optional[Boolean]`

whether to deliver (possibly out-of-date) cached files

Default value: ``undef``

##### <a name="max_wait"></a>`max_wait`

Data type: `Optional[Integer]`

how many seconds an approx(8) process will wait for a concurrent download

Default value: ``undef``

##### <a name="verbose"></a>`verbose`

Data type: `Optional[Boolean]`

whether informational messages should be printed in the log

Default value: ``undef``

##### <a name="debug"></a>`debug`

Data type: `Optional[Boolean]`

whether debugging messages should be printed in the log

Default value: ``undef``

##### <a name="config"></a>`config`

Data type: `Hash`

Hash of repositories to configure

Default value: `{}`

##### <a name="create_resources"></a>`create_resources`

Data type: `Hash`

a Hash of Hashes to create additional resources
 Defaults to {} (do not create any additional resources)

Default value: `{}`

### <a name="approxgarbage_collect"></a>`approx::garbage_collect`

Cronjob to run approx-gc

* **Note** approx-gc is not available in newer versions of approx
(@see https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=861947)

## Defined types

### <a name="approxrepository"></a>`approx::repository`

Add a repository line to an approx proxy

#### Examples

##### basic usage

```puppet
approx::repository{'debian-security':
  url => 'http://security.debian.org/debian-security',
}
```

#### Parameters

The following parameters are available in the `approx::repository` defined type:

* [`url`](#url)
* [`reponame`](#reponame)
* [`order`](#order)

##### <a name="url"></a>`url`

Data type: `String`

URL to add to the proxy

##### <a name="reponame"></a>`reponame`

Data type: `String`

Name for this repository on the approx proxy.
Defaults to $title.

Default value: `$title`

##### <a name="order"></a>`order`

Data type: `String`

Order for the concat.
Defaults to '50'

Default value: `'50'`

